/*
* Copyright (c) 2016 Razeware LLC
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*/

import UIKit

class ViewController: UIViewController {
  // MARK: UI properties
  var textField: UITextField!
  var segmentedControl: UISegmentedControl!
  var extractLabel: UILabel!
  var clearButton: UIButton!
  var imageView: UIImageView!
  
  // MARK: Private properties
  fileprivate var currentWikiPage: WikiPage? {
    didSet {
      updateUserInterface()
    }
  }
  
  override func viewDidLoad() {
    super.viewDidLoad()

    resetUserInterface() // Hide empty UI
  }
  
  // MARK: Add Action Methods Here
  
  
  // MARK: Add Protocol Methods Here
}

// MARK: - Private Helper Methods
private extension ViewController {
  func resetUserInterface() {
    extractLabel?.text = ""
    imageView?.image = nil
    imageView?.backgroundColor = .clear
    clearButton?.isHidden = true
  }
  
  func updateUserInterface() {
    if let currentWikiPage = currentWikiPage {
      extractLabel.text = currentWikiPage.extract
      clearButton.isHidden = false
      
      if let imageURLString = currentWikiPage.imageURLString,
        let url = URL(string: imageURLString) {
          URLSession.shared.dataTask(with: url) { (data: Data?, response: URLResponse?, error: Error?) -> Void in
            var image: UIImage? = nil
            if let data = data, error == nil {
              image = UIImage(data: data)
            }
            
            DispatchQueue.main.async {
              self.imageView.image = image
            }
            
            }.resume()
      }
    } else {
      resetUserInterface()
    }
  }
}

// MARK: - API Methods
private extension ViewController {
  func getWikiPageForText(_ text: String) {
    currentWikiPage = nil
    
    WikiService.getWikiForSearchString(text, language: Language(index: segmentedControl.selectedSegmentIndex)) { (wikiPage: WikiPage?) -> () in
      if let wikiPage = wikiPage {
        self.currentWikiPage = wikiPage
      } else {
        self.currentWikiPage = nil
        self.extractLabel.text = "No Results"
      }
    }
  }
  
  func getAlternateVersionFromPage(_ page: WikiPage) {
    currentWikiPage = nil
    
    WikiService.getAlternateVersionOfPage(page) { (wikiPage: WikiPage?) -> () in
      if let wikiPage = wikiPage {
        self.currentWikiPage = wikiPage
      } else {
        self.currentWikiPage = nil
        self.extractLabel.text = "No Results"
      }
    }
  }
}
