/*
* Copyright (c) 2016 Razeware LLC
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*/

import UIKit

extension UIView {
  func getRandomStartAndEndFrames() -> (start: CGRect, end: CGRect) {
    let startSide = Int(arc4random_uniform(4))
    var endSide   = startSide

    while endSide == startSide {
      endSide = Int(arc4random_uniform(4))
    }

    let startingFrame = randomFrameForSide(startSide)
    let endFrame = randomFrameForSide(endSide)

    return (startingFrame, endFrame)
  }

  func randomFrameForSide(_ side: Int) -> CGRect {
    guard let superview = superview else {
      return CGRect.zero
    }

    let edgePercent = CGFloat(arc4random()) / CGFloat(UINT32_MAX)
    var newFrame = frame

    switch side {
    case 0:
      newFrame.origin = CGPoint(x: superview.frame.width * edgePercent, y: -frame.width)
    case 1:
      newFrame.origin = CGPoint(x: superview.frame.width, y: superview.frame.height * edgePercent)
    case 2:
      newFrame.origin = CGPoint(x: superview.frame.width * edgePercent, y: superview.frame.height)
    case 3:
      newFrame.origin = CGPoint(x: -frame.width, y: superview.frame.height * edgePercent)
    default:
      break
    }
    return newFrame
  }
}
