/*
* Copyright (c) 2016 Razeware LLC
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*/

import UIKit

class FocusImageView: UIImageView {
  // 1
  override init(image: UIImage?) {
    super.init(image: image)
    // 2
    isUserInteractionEnabled = true
    // 3
    adjustsImageWhenAncestorFocused = false
  }

  // 4
  required init?(coder aDecoder: NSCoder) {
    super.init(coder: aDecoder)
  }

  override var canBecomeFocused: Bool {
    return true
  }

  // 1
  override func didUpdateFocus(in context: UIFocusUpdateContext, with coordinator: UIFocusAnimationCoordinator) {
    // 2
    if context.nextFocusedView == self {
      // 3
      coordinator.addCoordinatedAnimations({ () -> Void in
        self.transform = CGAffineTransform.identity.scaledBy(x: 2, y: 2)
        }, completion: nil)
      // 4
    } else if context.previouslyFocusedView == self {
      coordinator.addCoordinatedAnimations({ () -> Void in
        self.transform = CGAffineTransform.identity
        }, completion: nil)
    }
  }
}
