/*
* Copyright (c) 2016 Razeware LLC
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*/

import UIKit

class PlayAllVideoCategoryViewController: UIViewController {

  // MARK: - Outlets
  
  @IBOutlet weak var collectionView: UICollectionView!
  @IBOutlet var collectionViewDataSource: PlayAllVideoCategoryCollectionViewDataSource!
  
  // MARK: - Instance Variables
  
  var videoCategory: VideoCategory?
  
  var queuePlayerViewController: QueuePlayerViewController!
  let queuePlayerViewControllerSegue = "QueuePlayerViewControllerSegue"
  
  // MARK: - View Lifecycle
  
  override func viewDidLoad() {
    super.viewDidLoad()
    collectionViewDataSource.videoCategory = videoCategory
  }
  
  override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
    guard segue.identifier == queuePlayerViewControllerSegue else {
      return
    }
    let playerViewController = segue.destination
      as! QueuePlayerViewController
    queuePlayerViewController = playerViewController
    playerViewController.videoCategory = videoCategory
  }
}

// MARK: - Class Construtors

extension PlayAllVideoCategoryViewController {
  
  class func instanceWith(videoCategory: VideoCategory) ->
    PlayAllVideoCategoryViewController {
    
    let storyboard = UIStoryboard(name: "Main", bundle: .main)
    let identifier = "PlayAllVideoCategoryViewController"
    
    let viewController = storyboard.instantiateViewController(withIdentifier: identifier) as!
      PlayAllVideoCategoryViewController
    viewController.videoCategory = videoCategory
    viewController.title = videoCategory.name
    return viewController
  }
}
