/**
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */


import Foundation

let progressObservingContext: UnsafeMutableRawPointer? = nil

class ResourceManager {
  static let shared = ResourceManager()

  func requestVideoWith(tag: String,
    progressObserver: NSObject?,
    onSuccess: @escaping () -> Void,
    onFailure: @escaping (Error) -> Void) -> NSBundleResourceRequest {

      let videoRequest = NSBundleResourceRequest(tags: [tag])
      videoRequest.loadingPriority
        = NSBundleResourceRequestLoadingPriorityUrgent

      videoRequest.beginAccessingResources { error in
        OperationQueue.main.addOperation {
          if let progressObserver = progressObserver {
            videoRequest.progress.removeObserver(progressObserver,
              forKeyPath: "fractionCompleted")
          }

          if let error = error {
            onFailure(error)
          } else {
            onSuccess()
          }
        }
      }

      if let progressObserver = progressObserver {
        videoRequest.progress.addObserver(progressObserver,
          forKeyPath: "fractionCompleted",
          options: [.new, .initial],
          context: progressObservingContext)
      }

      return videoRequest
  }

  func requestCategoryWith(tag: String) -> NSBundleResourceRequest {
    let currentCategoryBundleRequest = NSBundleResourceRequest(tags: [tag])
    currentCategoryBundleRequest.loadingPriority = 0.5
    currentCategoryBundleRequest
      .beginAccessingResources { error in }
    return currentCategoryBundleRequest
  }
}
