/**
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import Foundation
import UIKit
import CloudKit

func showError(_ error: NSError?, inController controller: UIViewController?) {
  var controller = controller

  if controller == nil {
    controller = UIApplication.shared.windows.first!.rootViewController!
  }

  let title = "An error occurred."

  var message = error?.localizedDescription ?? ""
  if error?.domain == CKErrorDomain {
    if error!.code == CKError.Code.notAuthenticated.rawValue {
      message += "\n Log in to iCloud in the Settings app."
    }
  }

  let acceptButtonTitle = NSLocalizedString("OK", comment: "")

  let alertController = UIAlertController(title: title, message: message, preferredStyle: .alert)

  // Create the action.
  let acceptAction = UIAlertAction(title: acceptButtonTitle, style: .cancel) { _ in
  }

  // Add the action.
  alertController.addAction(acceptAction)

  DispatchQueue.main.async { controller?.present(alertController, animated: true, completion: nil) }
}
