/**
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import UIKit
import CloudKit

class MyMoviesViewController: UICollectionViewController {

  @IBOutlet var noMoviesView: UIView!

  override func viewDidLoad() {
    super.viewDidLoad()

    NotificationCenter.default.addObserver(self, selector: #selector(MyMoviesViewController.reload), name: MyMovieNotification, object: nil)
    reload()
  }

  var movies: [CKRecord]? {
    didSet {
      collectionView?.reloadData()
      updateMessage()

    }
  }

  override func viewWillAppear(_ animated: Bool) {
    super.viewWillAppear(animated)
    updateMessage()
  }

  private func updateMessage() {
    if movies?.count == 0 {
      self.view.addSubview(noMoviesView)
    } else {
      noMoviesView.removeFromSuperview()
    }
  }

  func reload() {
    GlobalModel.fetchMovies() { movieRecords, error in
      if let newMovies = movieRecords {
        self.movies = newMovies
      } else {
        showError(error, inController: self)
      }
    }
  }
}

extension MyMoviesViewController {
  override func numberOfSections(in collectionView: UICollectionView) -> Int {
    return 1
  }

  override func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
    return movies?.count ?? 0
  }

  override func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
    let cell = collectionView.dequeueReusableCell(withReuseIdentifier: MovieCell.Identifier, for: indexPath) as! MovieCell

    let movie = movies![(indexPath as NSIndexPath).row]
    cell.label.text = movie.title
    if let posterURL = movie.poster, let image = UIImage(contentsOfFile: posterURL) {
      cell.imageView.image = image
    } else {
      cell.imageView.image = UIImage(named: "posterPlaceholder")
    }
    return cell
  }

  override func collectionView(_ collectionView: UICollectionView, didSelectItemAt indexPath: IndexPath) {
    let movie = movies![(indexPath as NSIndexPath).row]

    let actionController = movie.movieActionController(presentingController: self, actionsToLeaveOut: .addToMovies)
    present(actionController, animated: true, completion: nil)
  }
}
