/**
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import Foundation
import CloudKit

protocol Movie {
  var title: String { get }
  var poster: String? { get }
  var synopsis: String? { get }
  var genre: String? { get }
  var year: Int? { get }

  var record: CKRecord { get }
}

extension Movie {
  var record: CKRecord {
    // Replace this stub with the code to build the CKRecord
    fatalError("not implemented yet")
  }
}

// MARK: - CKRecord as a Movie

let MovieRecordType = "Movie"

enum MovieFields: String {
  case title = "title"
  case poster = "poster"
  case year = "yearReleased"
  case genre = "genre"
  case averageRating = "averageRating"
  case numberOfRatings = "numberOfRatings"
  case synopsis = "synopsis"
}

extension CKRecord: Movie {
  subscript(key: MovieFields) -> CKRecordValue? {
    get {
      return self[key.rawValue]
    }
    set {
      self[key.rawValue] = newValue
    }
  }

  var record: CKRecord { return self }

  var title: String {
    get { return self[.title] as! String }
    set { self[.title] = newValue as NSString}
  }

  var year: Int? {
    get { return self[.year] as? Int }
    set { self[.year] = newValue != nil ? NSNumber(value: newValue!) : nil  }
  }

  var genre: String? {
    get { return self[.genre] as? String }
    set { self[.genre] = newValue != nil ? newValue! as NSString : nil}
  }

  var averageRating: Double? {
    get { return self[.averageRating] as? Double }
    set { self[.averageRating] = newValue != nil ? NSNumber(value: newValue!) : nil }
  }

  var numberOfRatings: Int {
    get { return self[.numberOfRatings] as? Int ?? 0 }
    set { self[.numberOfRatings] = NSNumber(value: newValue) }
  }

  var synopsis: String? {
    get { return self[.synopsis] as? String }
    set { self[.synopsis] = newValue != nil ? newValue! as NSString : nil }
  }

  var poster: String? {
    get {
      if let asset = self[.poster] as? CKAsset {
        return asset.fileURL.path
      }
      return nil
    }
    set {
      guard let path = newValue else { self[.poster] = nil; return }
      self[.poster] = CKAsset(fileURL: URL(string: path)!)
    }
  }
}
