/**
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import Foundation
import UIKit

class RatingViewController: UIViewController {

  var starRating = 0

  var movie: Movie!

  class func makeRatingController(_ movie: Movie) -> RatingViewController {
    let ratingBoard = UIStoryboard(name: "Rating", bundle: nil)
    let ratingController = ratingBoard.instantiateInitialViewController() as! RatingViewController
    ratingController.movie = movie
    return ratingController
  }

  override func viewWillAppear(_ animated: Bool) {
    super.viewWillAppear(animated)
  }

  override func didUpdateFocus(in context: UIFocusUpdateContext, with coordinator: UIFocusAnimationCoordinator) {
    super.didUpdateFocus(in: context, with: coordinator)

    if context.focusHeading == .right {
      starRating += 1
    } else if context.focusHeading == .left {
      starRating -= 1
    }

    for i in 1...5 {
      let highlight = i <= starRating
      (view.viewWithTag(i) as! UIControl).isHighlighted = highlight
    }
  }

  @IBAction func starSelected(_ sender: AnyObject) {
    print("selected \(sender.tag) stars")
    dismiss(animated: true, completion: nil)
    GlobalModel.setRating(movie, rating: starRating)
  }
}
