/**
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import UIKit

class MovieCell: UICollectionViewCell {
  static let Identifier = "MovieCell"

  // MARK: Properties

  static let reuseIdentifier = "DataItemCell"

  @IBOutlet weak var label: UILabel!

  @IBOutlet weak var imageView: UIImageView!

  var movie: Movie?

  // MARK: Initialization

  override func awakeFromNib() {
    super.awakeFromNib()


    // These properties are also exposed in Interface Builder.
    imageView.adjustsImageWhenAncestorFocused = true
    imageView.clipsToBounds = false

    label.alpha = 0.0
    label.textColor = UIColor.highlightColor
  }

  // MARK: UICollectionReusableView

  override func prepareForReuse() {
    super.prepareForReuse()

    // Reset the label's alpha value so it's initially hidden.
    label.alpha = 0.0
  }

  // MARK: UIFocusEnvironment

  override func didUpdateFocus(in context: UIFocusUpdateContext, with coordinator: UIFocusAnimationCoordinator) {
    /*
    Update the label's alpha value using the `UIFocusAnimationCoordinator`.
    This will ensure all animations run alongside each other when the focus
    changes.
    */
    coordinator.addCoordinatedAnimations({ [unowned self] in
      if self.isFocused {
        self.label.alpha = 1.0
      }
      else {
        self.label.alpha = 0.0
      }
      }, completion: nil)
  }
}
