/**
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import UIKit

class MainViewController: UIViewController {
  @IBOutlet weak var creditsLabel: UILabel!
  @IBOutlet weak var buyCreditsButton: UIButton!
  @IBOutlet weak var upgradeButton: UIButton!
  @IBOutlet weak var restoreButton: UIButton!
  @IBOutlet weak var topBar: UIView!

  let player = PlayerController()

  override func viewDidLoad() {
    super.viewDidLoad()
    let moviesController = self.childViewControllers[0] as! PurchasedMoviesViewController
    moviesController.parentController = self

    NotificationCenter.default.addObserver(self, selector: #selector(MainViewController.updateUI), name: NSNotification.Name(rawValue: productPurchasedNotification), object: nil)

    buyCreditsButton.layer.cornerRadius = 8.0
    buyCreditsButton.layer.masksToBounds = true
    upgradeButton.layer.cornerRadius = 8.0
    upgradeButton.layer.masksToBounds = true
    restoreButton.layer.cornerRadius = 8.0
    restoreButton.layer.masksToBounds = true

    updatefg()
  }

  private var focusGuide: UIFocusGuide!
  private func updatefg() {

    focusGuide = UIFocusGuide()
    focusGuide.preferredFocusedView = buyCreditsButton
    view.addLayoutGuide(focusGuide)
    view.addConstraints([focusGuide.topAnchor.constraint(equalTo: topBar.topAnchor),
      focusGuide.bottomAnchor.constraint(equalTo: topBar.bottomAnchor),
      focusGuide.leftAnchor.constraint(equalTo: topBar.leftAnchor),
      focusGuide.rightAnchor.constraint(equalTo: topBar.rightAnchor)
      ])

  }


  override func viewWillAppear(_ animated: Bool) {
    super.viewWillAppear(animated)
    updateUI()
  }

  func updateUI() { // can't be private due to nsnoticiation
    creditsLabel.text = "Credits Remaining: \(IAPHelper.Instance.creditsRemaining)"
    buyCreditsButton.isEnabled = IAPHelper.canMakePayments()
    if IAPHelper.Instance.upgradePurchased {
      upgradeButton?.removeFromSuperview()
    }
    let moviesController = self.childViewControllers[0] as! PurchasedMoviesViewController
    moviesController.collectionView?.reloadData()
  }

  func play(_ moviePath: String) {
    if IAPHelper.Instance.useCredit() {
      player.playVideo(moviePath, parent: self)
    }
  }

  // MARK: - IAP Actions

  @IBAction func upgradeToHD(_ sender: AnyObject) {
    IAPHelper.Instance.getUpgradeProduct { products, error in
      
      guard let upgradeProduct = products?.first else {
        print("error \(error)")
        return
      }
      
      IAPHelper.Instance.buyProduct(upgradeProduct)
    }
  }


  @IBAction func buyCredits(_ sender: AnyObject) {
    IAPHelper.Instance.buyCredits { products, error in
      // 1
      guard let creditProducts = products,
        creditProducts.count > 0 else {
          print("no credits to buy \(error)")
          return
      }
      
      // 2
      let buyAlert = UIAlertController(title: "Buy Movie Credits",
                                       message: nil, preferredStyle: .actionSheet)
      
      // 3
      let formatter = NumberFormatter()
      formatter.locale = creditProducts.first?.priceLocale
      formatter.numberStyle = .currency
      
      for product in creditProducts {
        // 4
        let title = "Buy " + product.localizedTitle + " for " +
          formatter.string(from: product.price)!
        let buyAction = UIAlertAction(title: title,
                                      style: .default,
                                      handler: { action in
                                        // 5
                                        IAPHelper.Instance.buyProduct(product)
        })
        buyAlert.addAction(buyAction)
      }
      
      let cancel = UIAlertAction(title: "Cancel",
                                 style: .cancel, handler: nil)
      buyAlert.addAction(cancel)
      
      self.present(buyAlert, animated: true, completion: nil)
    }
  }

  @IBAction func restorePurchases(_ sender: AnyObject) {
    IAPHelper.Instance.restoreCompletedTransactions()
  }

}
