/**
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import UIKit
import AVKit
import CoreImage

class PlayerController {

  var modernUIUnlocked: Bool { return IAPHelper.Instance.upgradePurchased }
  var border: UIImage { return UIImage(named: modernUIUnlocked ? "Modern" : "Old")! }

  func playVideo(_ moviePath: String, parent: UIViewController) {
    let url = URL(fileURLWithPath: moviePath)
    let item = getItem(url)

    let player = AVPlayer(playerItem: item)
    let vc = AVPlayerViewController()
    let imView = UIImageView(image: border)
    vc.view.addSubview(imView)
    vc.player = player
    parent.present(vc, animated: true, completion: {player.play()})
  }

  func getItem(_ url: URL) -> AVPlayerItem {
    let asset = AVAsset(url: url)
    let item = AVPlayerItem(asset: asset)

    if !modernUIUnlocked {
      let vidComp = AVVideoComposition(asset: asset,
        applyingCIFiltersWithHandler: { request in
          let filtered = request.sourceImage.applyingFilter("OldeFilm", withInputParameters: nil)
          request.finish(with: filtered, context: nil)
      })
      item.videoComposition = vidComp
    }
    return item
  }
}
