/**
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import Foundation
import StoreKit

private let productIdentifierPrefix = Bundle.main.bundleIdentifier! + "."
private let unlockModernFeatures = productIdentifierPrefix + "unlockModern"
private let movieCredits = productIdentifierPrefix + "movieCredits"
private let movieCredits10Pack = productIdentifierPrefix + "movieCredits.10pack"

let productPurchasedNotification = "ProductsPurchased"

class IAPHelper: NSObject {
  static let Instance = IAPHelper()

  var request: SKProductsRequest? = nil
  var completion: (([SKProduct]?, NSError?) -> Void)?

  class func canMakePayments() -> Bool {
    return SKPaymentQueue.canMakePayments()
  }

  override init() {
    super.init()

    // add transaction observer code here:
  }

  // MARK: - UPGRADE TO HD

  func getUpgradeProduct(_ completion:  @escaping (([SKProduct]?, NSError?) -> Void)) {
    // STUB to start the upgrade process
  }

  func completeUnlock() {
    // STUB replace this function
  }

  var upgradePurchased: Bool {
    return UserDefaults.standard.bool(forKey: "upgraded")
  }

  // MARK: - REUSABLE CODE


  private func getProducts(_ productIdentifiers: [String]) {
    // STUB to get the products
  }

  func buyProduct(_ product: SKProduct) {
    // STUB to do the purchase
  }

  private func postPurchaseUpdate() {
    NotificationCenter.default.post(name: Notification.Name(rawValue: productPurchasedNotification), object: nil)
  }

  // MARK: -

  func restoreCompletedTransactions() {
    // STUB replace this function
  }

  // MARK: - Movie Credits

  var creditsRemaining: Int {
    return 1
  }

  func buyCredits(_ completion: @escaping (([SKProduct]?, NSError?) -> Void)) {
    // STUB replace this function
  }

  func addCredits(_ numberOfCredits: Int) {
    // STUB replace this function
  }

  func useCredit() -> Bool {
    let credits = creditsRemaining
    guard credits > 0 else { return false }

    UserDefaults.standard.set(credits - 1, forKey: "credits")
    return true
  }

}

extension IAPHelper: SKProductsRequestDelegate {
  func productsRequest(_ request: SKProductsRequest, didReceive response: SKProductsResponse) {
    // STUB replace this method
  }

  func request(_ request: SKRequest, didFailWithError error: Error) {
    self.request = nil
    completion?(nil, error as NSError?)
  }

  func requestDidFinish(_ request: SKRequest) {
    self.request = nil
  }

}

extension IAPHelper: SKPaymentTransactionObserver {
  func paymentQueue(_ queue: SKPaymentQueue, updatedTransactions transactions: [SKPaymentTransaction]) {
    // STUB replace this method
  }

  private func completeTransaction(_ transaction: SKPaymentTransaction) {
    // STUB replace this method
  }

  private func restoreTransaction(_ transaction: SKPaymentTransaction) {
    // STUB replace this method
  }

  private func handlePurchase(_ productIdentifier: String) {
    switch productIdentifier {
    case unlockModernFeatures:
      completeUnlock()
    case movieCredits:
      addCredits(1)
    case movieCredits10Pack:
      addCredits(10)
    default:
      print("Unknown item purchased: \(productIdentifier)")
    }
  }

  private func failedTransaction(_ transaction: SKPaymentTransaction) {
    print("failedTransaction...")
    if (transaction.error as! NSError).code != SKError.Code.paymentCancelled.rawValue {
      print("Transaction error: \(transaction.error!.localizedDescription)")
    }
    SKPaymentQueue.default().finishTransaction(transaction)
  }
}

extension String: Error {

}
