/**
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import UIKit
import AVKit

class PurchasedMoviesViewController: UICollectionViewController {

  var moviePaths = [String]()
  var parentController: MainViewController!



  override func viewDidLoad() {
    super.viewDidLoad()
    loadMovies()
    collectionView?.reloadData()
  }

  func loadMovies() {
    let videoTypes = ["Animals", "City", "Food", "Nature"]
    for videoType in videoTypes {
      let paths = Bundle.main.paths(forResourcesOfType: "mp4", inDirectory: "videos/" + videoType)
      moviePaths += paths
    }
  }

  override func numberOfSections(in collectionView: UICollectionView) -> Int {
    return 1
  }

  override func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
    return moviePaths.count
  }

  override func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
    let cell = collectionView.dequeueReusableCell(withReuseIdentifier: "Cell", for: indexPath) as! MovieCell
    cell.backgroundColor = UIColor.green
    let path = moviePaths[(indexPath as NSIndexPath).row]
    let image = imageForMovie(path)
    cell.imageView.image = image
    return cell
  }

  override func collectionView(_ collectionView: UICollectionView, canFocusItemAt indexPath: IndexPath) -> Bool {
    return IAPHelper.Instance.creditsRemaining > 0
  }

  override func collectionView(_ collectionView: UICollectionView, willDisplay cell: UICollectionViewCell, forItemAt indexPath: IndexPath) {
    cell.alpha = IAPHelper.Instance.creditsRemaining > 0 ? 1 : 0.5
  }

  override func collectionView(_ collectionView: UICollectionView, didSelectItemAt indexPath: IndexPath) {
    let path = moviePaths[(indexPath as NSIndexPath).row]
    parentController.play(path)
  }
}

func imageForMovie(_ path: String) -> UIImage? {
  let asset = AVURLAsset(url: URL(fileURLWithPath: path))
  let generator = AVAssetImageGenerator(asset: asset)
  let requestedTime = CMTime(seconds: 1, preferredTimescale: 60)
  let imageRef = try? generator.copyCGImage(at: requestedTime, actualTime: nil)
  let thumbnailImage = UIImage(cgImage: imageRef!)
  return thumbnailImage
}
