/*
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import UIKit
import Photos

class SlideshowsViewController: UICollectionViewController {
  
  @IBOutlet weak var emptySlideshowView: UIView!
  
  // MARK: - Variables
  fileprivate let reuseIdentifier = "SlideshowCell"
  
  // Segues
  enum Segues: String {
    case SegueSlideshowsToAssetPicker
    case SegueSlideshowsToSlideshowDetail
  }
  
  fileprivate var slideshows: [Slideshow] = [] {
    didSet {
      emptySlideshowView.isHidden = slideshows.count > 0
    }
  }
  private var assetsFetchResults: PHFetchResult<PHAsset>?
  fileprivate var slideshowAssets: [PHAsset]?
  fileprivate var thumbnailSize = CGSize.zero
  fileprivate let imageManager = PHImageManager()
  
  
  override func viewDidLoad() {
    super.viewDidLoad()
    
    self.navigationItem.leftBarButtonItem = nil
    self.splitViewController?.preferredDisplayMode = .primaryHidden
    
  }
  
  override func viewWillAppear(_ animated: Bool) {
    super.viewWillAppear(animated)
    
    // Determine the size of the thumbnails to request from the PHCachingImageManager
    let scale = UIScreen.main.scale
    let cellSize = (collectionViewLayout as! UICollectionViewFlowLayout).itemSize
    thumbnailSize = CGSize(width: cellSize.width * scale, height: cellSize.height * scale)
    
    // Load and display slideshows
    loadSlideshows()
  }
  
  // MARK: - Navigation
  override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
    if segue.identifier == Segues.SegueSlideshowsToSlideshowDetail.rawValue {
      let destination = segue.destination as! SlideshowPageViewController
      let indexPath = collectionView!.indexPath(for: sender as! GridViewCell)!
      let slideshow = slideshows[indexPath.item] 
      destination.slideshow = slideshow
    } else if segue.identifier == Segues.SegueSlideshowsToAssetPicker.rawValue {
      let destination = (segue.destination as! UINavigationController).childViewControllers.first as! AssetGridViewController
      destination.selectedAssets = SelectedAssets()
    }
  }
  
  // MARK: - Private helper methods
  private func slideshowAssetForIdentifier(_ identifier: String) -> PHAsset? {
    if let fetchResults = assetsFetchResults {
      for i in 0..<fetchResults.count {
        if fetchResults.object(at: i).localIdentifier == identifier {
          return fetchResults.object(at: i)
        }
      }
    }
    return nil
  }
  
  private func loadSlideshows() {
    // Get stored slideshows
    slideshows = SlideshowManager.sharedInstance.slideshows
    // Fetch thumbnails for slideshows, thumbnails are the first asset in the slideshow
    if slideshows.count > 0 {
      let thumbnailIdentifiers = slideshows.map { slideshow in slideshow.thumbnailIdentifier()! }
      assetsFetchResults = PHAsset.fetchAssets(withLocalIdentifiers: thumbnailIdentifiers, options: nil)
      slideshowAssets = slideshows.map { slideshow in slideshowAssetForIdentifier(slideshow.thumbnailIdentifier()!)!
      }
    }
    // Display data in collection view
    collectionView!.reloadData()
  }
  
}

// MARK: - UICollectionViewDelegate, UICollectionViewDataSource
extension SlideshowsViewController {
  override func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
    return slideshows.count
  }
  
  override func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
    let cell = collectionView.dequeueReusableCell(withReuseIdentifier: reuseIdentifier, for: indexPath) as! GridViewCell
    
    // Configure the cell
    let asset = slideshowAssets![indexPath.item]
    let options = PHImageRequestOptions()
    options.isNetworkAccessAllowed = true
    
    cell.representedAssetIdentifier = asset.localIdentifier
    imageManager.requestImage(for: asset,
                              targetSize: thumbnailSize,
                              contentMode: .aspectFill,
                              options: options)
    { image, _ in
      if cell.representedAssetIdentifier == asset.localIdentifier {
        cell.thumbnailImage = image
      }
    }
    
    cell.label.text = slideshows[indexPath.item].getTitle()
    
    return cell
  }
  
}
