/*
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import UIKit
import Photos

class MasterViewController: UITableViewController {
  
  // Segues
  enum Segues: String {
    case SegueMasterToSlideShows
    case SegueAssetPicker
  }
  
  var detailViewController: AssetGridViewController? = nil
  var selectedAssets: SelectedAssets?
  
  fileprivate let sectionNames = ["","","Albums"]
  
  override func viewDidLoad() {
    super.viewDidLoad()

    if let split = self.splitViewController {
      let controllers = split.viewControllers
      self.detailViewController = (controllers[controllers.count-1] as! UINavigationController).topViewController as? AssetGridViewController
    }
    
    if selectedAssets == nil {
      selectedAssets = SelectedAssets()
    }
    
    // TBD: Request access to Photos Library
  }
  
  override func viewWillAppear(_ animated: Bool) {
    self.clearsSelectionOnViewWillAppear = self.splitViewController!.isCollapsed
    super.viewWillAppear(animated)
    tableView.reloadData()
  }
  
  // MARK: - Segues
  override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
    if segue.identifier == Segues.SegueAssetPicker.rawValue {
      if let indexPath = self.tableView.indexPathForSelectedRow {
        let destination = (segue.destination as! UINavigationController).childViewControllers.first as! AssetGridViewController
        let cell = sender as! UITableViewCell
        destination.title = cell.textLabel?.text
        destination.selectedAssets = selectedAssets
        destination.delegate = self
        
        // TBD: Display asset collection metadata
        switch (indexPath.section) {
        default:
          break
        }
      }
    }
  }
  
  // MARK: - Private helper methods
  func showNoAccessAlertAndCancel() {
    let alert = UIAlertController(title: "No Photo Permissions", message: "Please grant photo permissions in Settings", preferredStyle: .alert)
    alert.addAction(UIAlertAction(title: "Cancel", style: .cancel, handler: nil))
    alert.addAction(UIAlertAction(title: "Settings", style: .default, handler: { _ in
      UIApplication.shared.open(
        URL(string: UIApplicationOpenSettingsURLString)!,
        options: [:],
        completionHandler: nil)
      return
    }))
    
    self.present(alert, animated: true, completion: nil)
  }
}

// MARK: - Table View
extension MasterViewController {
  override func numberOfSections(in tableView: UITableView) -> Int {
    return sectionNames.count
  }
  
  override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
    return 1
  }
  
  override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
    let cell = tableView.dequeueReusableCell(withIdentifier: "Cell", for: indexPath)
    cell.textLabel!.text = ""
    
    switch(indexPath.section) {
    case 0:
      cell.textLabel!.text = "Selected"
    case 1:
      // All Photos and Favorites
      cell.textLabel!.text = "All Photos"
    case 2:
      // Albums
      cell.textLabel!.text = "Albums"
    default:
      break
    }
    return cell
  }
}

extension MasterViewController: AssetPickerDelegate {
  func assetPickerDidCancel() {
    // Do nothing for now
  }
  
  func assetPickerDidFinishPickingAssets(_ selectedAssets: [PHAsset])  {
    // TBD: Create a new slideshow
  }
}

