/*
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import Foundation
import Photos

class SlideshowManager: NSObject {
  var slideshows: [Slideshow]
  
  static let slideshowKey = "Slideshow"
  static let sharedInstance = SlideshowManager()
  
  override init() {
    if let data = UserDefaults.standard.object(forKey: SlideshowManager.slideshowKey) as? Data,
      let slideshowData = NSKeyedUnarchiver.unarchiveObject(with: data) as? [Slideshow] {
      slideshows = slideshowData
    } else {
      slideshows = []
    }
  }
  
  init(slideshows:[Slideshow]) {
    self.slideshows = slideshows
  }
  
  // MARK: - Helpers
  func addSlideshow(_ slideshow: Slideshow) {
    slideshows.append(slideshow)
    saveAllSlideshows()
  }
  
  func updateSlideshow(_ slideshow: Slideshow) {
    // May need to replace an existing one
    var changedSlideshow = false
    for i in 0..<slideshows.count {
      if slideshows[i].getKey() == slideshow.getKey() {
        changedSlideshow = true
        // Update changed data
        slideshows[i] = slideshow
        break
      }
    }
    if changedSlideshow {
      saveAllSlideshows()
    }
  }
  
  func getSlideshow(_ key: String) -> Slideshow? {
    for i in 0..<slideshows.count {
      if slideshows[i].getKey() == key {
        return slideshows[i]
      }
    }
    return nil
  }
  
  func saveAllSlideshows() {
    guard slideshows.count > 0 else { return }
    // Don't save image to defaults due to lack of space. Image is only
    // used to send info to collaborators
    let savedSlideshows: [Slideshow] = slideshows.map { slideshow in
      slideshow.clearImage()
      return slideshow
    }
    let data = NSKeyedArchiver.archivedData(withRootObject: savedSlideshows)
    UserDefaults.standard.set(data, forKey: SlideshowManager.slideshowKey)
    UserDefaults.standard.synchronize()
  }
}
