/*
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import Foundation
import MultipeerConnectivity

class PeerToPeerConnectionManager: NSObject {
  static let sharedInstance = PeerToPeerConnectionManager()
  
  var slideshow: Slideshow!
  
  private let serviceType = "rw-fuse"
  fileprivate let archiveClassName = "Sliders.Slideshow"
  
  private let peerId = MCPeerID(displayName: UIDevice.current.name)
  private var session: MCSession?
  
  func setupPeerToPeerBrowser() -> MCBrowserViewController {
    if session == nil {
      session = MCSession(peer: peerId, securityIdentity: nil, encryptionPreference: .none)
      session?.delegate = self
    }
    return MCBrowserViewController(serviceType: serviceType, session: session!)
  }
  
  // MARK: - Helpers
  func sendSlideshow(_ slideshow: Slideshow) {
    let data = NSKeyedArchiver.archivedData(withRootObject: slideshow)
    do {
      try session?.send(data, toPeers: [(session?.connectedPeers[0])!], with: .reliable)
    } catch {
      // Do nothing
    }
  }
  
  func send(_ image: UIImage, to slideshow: Slideshow) {
    let info = ["slideshowKey": slideshow.getKey(), "asset": image] as [String : Any]
    let data = NSKeyedArchiver.archivedData(withRootObject: info)
    do {
      try session?.send(data, toPeers: [(session?.connectedPeers[0])!], with: .reliable)
    } catch {
      // Do nothing
    }
  }
  
  func isConnected() -> Bool {
    if let connectedPeers = session?.connectedPeers {
      return connectedPeers.count > 0
    }
    return false
  }

}

// MARK: - MCSessionDelegate
extension PeerToPeerConnectionManager: MCSessionDelegate {
  func session(_ session: MCSession, didReceive data: Data, fromPeer peerID: MCPeerID) {
    NSKeyedUnarchiver.setClass(Slideshow.self, forClassName: archiveClassName)
    if let data = NSKeyedUnarchiver.unarchiveObject(with: data) as? Slideshow {
      DispatchQueue.main.async{
        self.slideshow = data
        NotificationCenter.default.post(Notification.init(name: .dataReceived))
      }
    }
  }
  func session(_ session: MCSession, didReceive stream: InputStream, withName streamName: String, fromPeer peerID: MCPeerID) {
    //
  }
  func session(_ session: MCSession, didStartReceivingResourceWithName resourceName: String, fromPeer peerID: MCPeerID, with progress: Progress) {
    //
  }
  func session(_ session: MCSession, didFinishReceivingResourceWithName resourceName: String, fromPeer peerID: MCPeerID, at localURL: URL, withError error: Error?) {
    //
  }
  func session(_ session: MCSession, peer peerID: MCPeerID, didChange state: MCSessionState) {
    if state == .connected {
      print("Connected to \(peerID.displayName)")
    }
  }
}

// MARK: - Notification
extension Notification.Name {
  static let dataReceived = Notification.Name("com.razeware.apps.Fuse:DataReceived")
}
