/*
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import UIKit

class SlideshowEditViewController: UIViewController {
  
  @IBOutlet weak var imageView: UIImageView!
  @IBOutlet weak var titleTextField: UITextField!
  @IBOutlet weak var pickerView: UIPickerView!
  
  var slideshow: Slideshow!
  var selectedTheme: String?
  
  let themes = ["black", "red", "green", "blue"]
  
  override func viewDidLoad() {
    super.viewDidLoad()
    
    // Do any additional setup after loading the view.
    let gestureRecognizer = UITapGestureRecognizer(target: self, action: #selector(dismissKeyboard))
    gestureRecognizer.cancelsTouchesInView = false
    self.view.addGestureRecognizer(gestureRecognizer)
  }
  
  override func viewWillAppear(_ animated: Bool) {
    super.viewWillAppear(animated)
    titleTextField.text = slideshow.getTitle()
    let theme = slideshow.getTheme()
    if let indexOfTheme = themes.index(of: theme) {
      selectedTheme = themes[indexOfTheme]
      pickerView.selectRow(indexOfTheme, inComponent: 0, animated: false)
    } else {
      pickerView.selectRow(0, inComponent: 0, animated: false)
    }
    imageView.image = slideshow.getImage()
  }
  
  func dismissKeyboard() {
    self.view.endEditing(true)
  }
  
  @IBAction func cancelPressed(_ sender: AnyObject) {
    self.dismiss(animated: true, completion: nil)
  }
  
  @IBAction func savePressed(_ sender: AnyObject) {
    if let newTitle = titleTextField.text {
      if slideshow.getTitle() != newTitle {
        slideshow.setTitle(newTitle)
      }
      
    }
    if let newTheme = selectedTheme {
      if slideshow.getTheme() != newTheme {
        slideshow.setTheme(newTheme)
      }
    }
    PeerToPeerConnectionManager.sharedInstance.sendSlideshow(slideshow)
    self.dismiss(animated: true, completion: nil)
  }
}

// MARK: - UIPickerViewDelegate, UIPickerViewDataSource, UIPickerViewDelegate
extension SlideshowEditViewController: UIPickerViewDataSource, UIPickerViewDelegate {
  func numberOfComponents(in pickerView: UIPickerView) -> Int {
    return 1
  }
  
  func pickerView(_ pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int {
    return themes.count
  }
  
  func pickerView(_ pickerView: UIPickerView, titleForRow row: Int, forComponent component: Int) -> String? {
    return themes[row]
  }
  
  func pickerView(_ pickerView: UIPickerView, didSelectRow row: Int, inComponent component: Int) {
    selectedTheme = themes[row]
  }
}
