/**
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import Foundation
import TVServices

class ServiceProvider: NSObject, TVTopShelfProvider {

  override init() {
      super.init()
  }

  // MARK: - TVTopShelfProvider protocol

  var topShelfStyle: TVTopShelfContentStyle {
      // Return desired Top Shelf style.
      return .sectioned
  }

  var topShelfItems: [TVContentItem] {
    let breakingNewsIdentifier = TVContentIdentifier(identifier: "Breaking News", container: nil)!
    let breakingNewsSection = TVContentItem(contentIdentifier: breakingNewsIdentifier)!
    breakingNewsSection.title = "Breaking News"

    let martianRiotIdentifier = TVContentIdentifier(identifier: "Martian Riot", container: nil)!
    let martianRiotItem = TVContentItem(contentIdentifier: martianRiotIdentifier)!
    martianRiotItem.displayURL = urlFor(identifier: "martianRiot")
    martianRiotItem.imageURL = Bundle.main.url(forResource: "sectionedMartians", withExtension: "png")
    breakingNewsSection.topShelfItems = [martianRiotItem]


    let milkyWayNewsIdentifier = TVContentIdentifier(identifier: "Milky Way News", container: nil)!
    let milkyWaySection = TVContentItem(contentIdentifier: milkyWayNewsIdentifier)!
    milkyWaySection.title = "Milky Way"

    let cometIdentifier = TVContentIdentifier(identifier: "An odd comet", container: nil)!
    let cometItem = TVContentItem(contentIdentifier: cometIdentifier)!
    cometItem.displayURL = urlFor(identifier: "comet")
    cometItem.imageURL = Bundle.main.url(forResource: "comet", withExtension: "png")

    let asteroidIdentifier = TVContentIdentifier(identifier:
      "Asteroid Light Speed", container: nil)!
    let asteroidItem = TVContentItem(contentIdentifier:
      asteroidIdentifier)!
    asteroidItem.imageURL = Bundle.main.url(forResource:
      "asteroid", withExtension: "png")
    asteroidItem.displayURL = urlFor(identifier: "asteroid")
    
    milkyWaySection.topShelfItems = [cometItem, asteroidItem]

    return [breakingNewsSection, milkyWaySection]
  }

  private func urlFor(identifier: String) -> URL {
    var components = URLComponents()
    components.scheme = "newsapp"
    components.queryItems = [URLQueryItem(name: "identifier", value: identifier)]

    return components.url!
  }
}

