// AVAILABLE HERE: http://bit.ly/1mMnWX8

/***********************************************************
 * ASYNC & PROMISES in JavaScript [COMPLETE]
 ***********************************************************/

/* ASYNCHRONOUS FUNCTIONS */

function asyncUpperCase(str, callback) {
  setTimeout(() => {
    callback(str.toUpperCase());
  }, 200);
}

function asyncRepeatString(str, count, callback) {
  setTimeout(() => {
    callback(str.repeat(count));
  });
}

function asyncReverseString(str, callback) {
  setTimeout(() => {
    callback(str.split('').reverse().join(''));
  }, 100);
}


/* Demonstrating async usage */
asyncUpperCase("hellO", console.log);
asyncRepeatString("hello", 4, console.log);
asyncReverseString("hello", console.log);


/* Callback-hell */
asyncUpperCase("hello", str => {
  asyncRepeatString(str, 4, rptStr => {
    asyncReverseString(rptStr, console.log);
  });
});



/* PROMISES */

function upperCase(str) {
  return new Promise((resolve, reject) => {
    asyncUpperCase(str, resolve);
  });
}

function repeatString(str, count) {
  return new Promise((resolve, reject) => {
    asyncRepeatString(str, count, resolve);
  });
}

function reverseString(str) {
  return new Promise((resolve, reject) => {
    asyncReverseString(str, resolve);
  });
}



upperCase("hello")
  .then(reverseString)
  .then(str => repeatString(str, 4))
  .then(console.log);


/* WRAPPING XMLHTTPREQUEST */

function get(url) {
  return new Promise((resolve, reject) => {
    // 1:
    const req = new XMLHttpRequest();
    // 2:
    req.open("GET", url);
    // 3:
    req.onload = () => {
      if (req.status == 200) {
        // 4:
        resolve(req.response);
      }
      else {
        // 5:
        reject(Error(req.statusText));
      }
    };
    // 6:
    req.onerror = () => reject(Error("Network Error"));
    // 7:
    req.send();
  });
}


function getJSON(url) {
  return get(url).then(JSON.parse);
}

getJSON("https://httpbin.org/ip")
  .then(console.log);


